@@ -6,14 +6,28 @@
 
 # Add any Sphinx extension module names here, as strings. They can be extensions
 # coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
-extensions = ['sphinx.ext.autodoc', 'sphinx.ext.viewcode', 'openstackdocstheme']
+extensions = [
+    'sphinx.ext.autodoc',
+    'sphinx.ext.viewcode',
+    'sphinxcontrib.apidoc',
+    'openstackdocstheme',
+    'cliff.sphinxext']
 
 # openstackdocstheme options
-repository_name = 'openstack/python-designateclient'
-bug_project = 'python-designateclient'
-bug_tag = ''
+openstackdocs_repo_name = 'openstack/python-designateclient'
+openstackdocs_bug_project = 'python-designateclient'
+openstackdocs_bug_tag = ''
 html_theme = 'openstackdocs'
 
+apidoc_module_dir = '../../designateclient'
+apidoc_output_dir = 'reference/api'
+apidoc_excluded_paths = [ 'tests/*', 'functionaltests/*' ]
+apidoc_separate_modules = True
+
+autodoc_exclude_modules = [
+  'designateclient.tests.*',
+  'designateclient.functionaltests.*']
+
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ['_templates']
 
@@ -24,25 +38,14 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'designateclient'
 copyright = u'2012, Managed I.T. 2013-2014, Hewlett-Packard Development Company, L.P.'
 
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
-#
-# The short X.Y version.
-from designateclient.version import version_info as designateclient_version
-version = designateclient_version.canonical_version_string()
-# The full version, including alpha/beta/rc tags.
-release = designateclient_version.version_string_with_vcs()
-
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
 exclude_patterns = []
 
 # The name of the Pygments (syntax highlighting) style to use.
-pygments_style = 'sphinx'
+pygments_style = 'native'
 
 # A list of ignored prefixes for module index sorting.
 modindex_common_prefix = ['designateclient']
